# OpenAPIClient

The spoonacular Nutrition, Recipe, and Food API allows you to access over thousands of recipes, thousands of ingredients, 800,000 food products, over 100,000 menu items, and restaurants. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.

Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.

This ObjC package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1
- Package version: 1.1.1
- Build package: org.openapitools.codegen.languages.ObjcClientCodegen
For more information, please visit [https://spoonacular.com/contact](https://spoonacular.com/contact)

## Requirements

The SDK requires [**ARC (Automatic Reference Counting)**](http://stackoverflow.com/questions/7778356/how-to-enable-disable-automatic-reference-counting) to be enabled in the Xcode project.

## Installation & Usage
### Install from Github using [CocoaPods](https://cocoapods.org/)

Add the following to the Podfile:

```ruby
pod 'OpenAPIClient', :git => 'https://github.com/ddsky/spoonacular-api-clients/tree/master/objc/.git'
```

To specify a particular branch, append `, :branch => 'branch-name-here'`

To specify a particular commit, append `, :commit => '11aa22'`

### Install from local path using [CocoaPods](https://cocoapods.org/)

Put the SDK under your project folder (e.g. /path/to/objc_project/Vendor/OpenAPIClient) and then add the following to the Podfile:

```ruby
pod 'OpenAPIClient', :path => 'Vendor/OpenAPIClient'
```

### Usage

Import the following:

```objc
#import <OpenAPIClient/OAIApiClient.h>
#import <OpenAPIClient/OAIDefaultConfiguration.h>
// load models
#import <OpenAPIClient/OAIAddMealPlanTemplate200Response.h>
#import <OpenAPIClient/OAIAddMealPlanTemplate200ResponseItemsInner.h>
#import <OpenAPIClient/OAIAddMealPlanTemplate200ResponseItemsInnerValue.h>
#import <OpenAPIClient/OAIAddToMealPlanRequest.h>
#import <OpenAPIClient/OAIAddToMealPlanRequest1.h>
#import <OpenAPIClient/OAIAddToMealPlanRequest1Value.h>
#import <OpenAPIClient/OAIAddToMealPlanRequest1ValueIngredientsInner.h>
#import <OpenAPIClient/OAIAddToShoppingListRequest.h>
#import <OpenAPIClient/OAIAnalyzeARecipeSearchQuery200Response.h>
#import <OpenAPIClient/OAIAnalyzeARecipeSearchQuery200ResponseDishesInner.h>
#import <OpenAPIClient/OAIAnalyzeARecipeSearchQuery200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIAnalyzeRecipeInstructions200Response.h>
#import <OpenAPIClient/OAIAnalyzeRecipeInstructions200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInner.h>
#import <OpenAPIClient/OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.h>
#import <OpenAPIClient/OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.h>
#import <OpenAPIClient/OAIAnalyzeRecipeRequest.h>
#import <OpenAPIClient/OAIAnalyzeRecipeRequest1.h>
#import <OpenAPIClient/OAIAutocompleteIngredientSearch200ResponseInner.h>
#import <OpenAPIClient/OAIAutocompleteMenuItemSearch200Response.h>
#import <OpenAPIClient/OAIAutocompleteProductSearch200Response.h>
#import <OpenAPIClient/OAIAutocompleteProductSearch200ResponseResultsInner.h>
#import <OpenAPIClient/OAIAutocompleteRecipeSearch200ResponseInner.h>
#import <OpenAPIClient/OAIClassifyCuisine200Response.h>
#import <OpenAPIClient/OAIClassifyGroceryProduct200Response.h>
#import <OpenAPIClient/OAIClassifyGroceryProductBulk200ResponseInner.h>
#import <OpenAPIClient/OAIClassifyGroceryProductBulkRequestInner.h>
#import <OpenAPIClient/OAIClassifyGroceryProductRequest.h>
#import <OpenAPIClient/OAIClearMealPlanDayRequest.h>
#import <OpenAPIClient/OAIComputeGlycemicLoad200Response.h>
#import <OpenAPIClient/OAIComputeGlycemicLoad200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIComputeGlycemicLoadRequest.h>
#import <OpenAPIClient/OAIComputeIngredientAmount200Response.h>
#import <OpenAPIClient/OAIConnectUser200Response.h>
#import <OpenAPIClient/OAIConnectUserRequest.h>
#import <OpenAPIClient/OAIConvertAmounts200Response.h>
#import <OpenAPIClient/OAICreateRecipeCard200Response.h>
#import <OpenAPIClient/OAIDeleteFromMealPlanRequest.h>
#import <OpenAPIClient/OAIDetectFoodInText200Response.h>
#import <OpenAPIClient/OAIDetectFoodInText200ResponseAnnotationsInner.h>
#import <OpenAPIClient/OAIGenerateMealPlan200Response.h>
#import <OpenAPIClient/OAIGenerateMealPlan200ResponseNutrients.h>
#import <OpenAPIClient/OAIGenerateShoppingList200Response.h>
#import <OpenAPIClient/OAIGenerateShoppingListRequest.h>
#import <OpenAPIClient/OAIGetARandomFoodJoke200Response.h>
#import <OpenAPIClient/OAIGetAnalyzedRecipeInstructions200Response.h>
#import <OpenAPIClient/OAIGetAnalyzedRecipeInstructions200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner.h>
#import <OpenAPIClient/OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.h>
#import <OpenAPIClient/OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.h>
#import <OpenAPIClient/OAIGetComparableProducts200Response.h>
#import <OpenAPIClient/OAIGetComparableProducts200ResponseComparableProducts.h>
#import <OpenAPIClient/OAIGetComparableProducts200ResponseComparableProductsProteinInner.h>
#import <OpenAPIClient/OAIGetConversationSuggests200Response.h>
#import <OpenAPIClient/OAIGetConversationSuggests200ResponseSuggests.h>
#import <OpenAPIClient/OAIGetConversationSuggests200ResponseSuggestsInner.h>
#import <OpenAPIClient/OAIGetDishPairingForWine200Response.h>
#import <OpenAPIClient/OAIGetIngredientInformation200Response.h>
#import <OpenAPIClient/OAIGetIngredientInformation200ResponseNutrition.h>
#import <OpenAPIClient/OAIGetIngredientSubstitutes200Response.h>
#import <OpenAPIClient/OAIGetMealPlanTemplate200Response.h>
#import <OpenAPIClient/OAIGetMealPlanTemplate200ResponseDaysInner.h>
#import <OpenAPIClient/OAIGetMealPlanTemplate200ResponseDaysInnerItemsInner.h>
#import <OpenAPIClient/OAIGetMealPlanTemplate200ResponseDaysInnerItemsInnerValue.h>
#import <OpenAPIClient/OAIGetMealPlanTemplates200Response.h>
#import <OpenAPIClient/OAIGetMealPlanWeek200Response.h>
#import <OpenAPIClient/OAIGetMealPlanWeek200ResponseDaysInner.h>
#import <OpenAPIClient/OAIGetMealPlanWeek200ResponseDaysInnerItemsInner.h>
#import <OpenAPIClient/OAIGetMealPlanWeek200ResponseDaysInnerItemsInnerValue.h>
#import <OpenAPIClient/OAIGetMealPlanWeek200ResponseDaysInnerNutritionSummary.h>
#import <OpenAPIClient/OAIGetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner.h>
#import <OpenAPIClient/OAIGetMenuItemInformation200Response.h>
#import <OpenAPIClient/OAIGetProductInformation200Response.h>
#import <OpenAPIClient/OAIGetProductInformation200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIGetRandomFoodTrivia200Response.h>
#import <OpenAPIClient/OAIGetRandomRecipes200Response.h>
#import <OpenAPIClient/OAIGetRandomRecipes200ResponseRecipesInner.h>
#import <OpenAPIClient/OAIGetRecipeEquipmentByID200Response.h>
#import <OpenAPIClient/OAIGetRecipeEquipmentByID200ResponseEquipmentInner.h>
#import <OpenAPIClient/OAIGetRecipeInformation200Response.h>
#import <OpenAPIClient/OAIGetRecipeInformation200ResponseExtendedIngredientsInner.h>
#import <OpenAPIClient/OAIGetRecipeInformation200ResponseExtendedIngredientsInnerMeasures.h>
#import <OpenAPIClient/OAIGetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric.h>
#import <OpenAPIClient/OAIGetRecipeInformation200ResponseWinePairing.h>
#import <OpenAPIClient/OAIGetRecipeInformation200ResponseWinePairingProductMatchesInner.h>
#import <OpenAPIClient/OAIGetRecipeInformationBulk200ResponseInner.h>
#import <OpenAPIClient/OAIGetRecipeIngredientsByID200Response.h>
#import <OpenAPIClient/OAIGetRecipeIngredientsByID200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIGetRecipeNutritionWidgetByID200Response.h>
#import <OpenAPIClient/OAIGetRecipeNutritionWidgetByID200ResponseBadInner.h>
#import <OpenAPIClient/OAIGetRecipeNutritionWidgetByID200ResponseGoodInner.h>
#import <OpenAPIClient/OAIGetRecipePriceBreakdownByID200Response.h>
#import <OpenAPIClient/OAIGetRecipePriceBreakdownByID200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAIGetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount.h>
#import <OpenAPIClient/OAIGetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric.h>
#import <OpenAPIClient/OAIGetRecipeTasteByID200Response.h>
#import <OpenAPIClient/OAIGetShoppingList200Response.h>
#import <OpenAPIClient/OAIGetShoppingList200ResponseAislesInner.h>
#import <OpenAPIClient/OAIGetShoppingList200ResponseAislesInnerItemsInner.h>
#import <OpenAPIClient/OAIGetShoppingList200ResponseAislesInnerItemsInnerMeasures.h>
#import <OpenAPIClient/OAIGetSimilarRecipes200ResponseInner.h>
#import <OpenAPIClient/OAIGetWineDescription200Response.h>
#import <OpenAPIClient/OAIGetWinePairing200Response.h>
#import <OpenAPIClient/OAIGetWinePairing200ResponseProductMatchesInner.h>
#import <OpenAPIClient/OAIGetWineRecommendation200Response.h>
#import <OpenAPIClient/OAIGetWineRecommendation200ResponseRecommendedWinesInner.h>
#import <OpenAPIClient/OAIGuessNutritionByDishName200Response.h>
#import <OpenAPIClient/OAIGuessNutritionByDishName200ResponseCalories.h>
#import <OpenAPIClient/OAIGuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent.h>
#import <OpenAPIClient/OAIImageAnalysisByURL200Response.h>
#import <OpenAPIClient/OAIImageAnalysisByURL200ResponseCategory.h>
#import <OpenAPIClient/OAIImageAnalysisByURL200ResponseNutrition.h>
#import <OpenAPIClient/OAIImageAnalysisByURL200ResponseNutritionCalories.h>
#import <OpenAPIClient/OAIImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent.h>
#import <OpenAPIClient/OAIImageAnalysisByURL200ResponseRecipesInner.h>
#import <OpenAPIClient/OAIImageClassificationByURL200Response.h>
#import <OpenAPIClient/OAIIngredientSearch200Response.h>
#import <OpenAPIClient/OAIIngredientSearch200ResponseResultsInner.h>
#import <OpenAPIClient/OAIMapIngredientsToGroceryProducts200ResponseInner.h>
#import <OpenAPIClient/OAIMapIngredientsToGroceryProducts200ResponseInnerProductsInner.h>
#import <OpenAPIClient/OAIMapIngredientsToGroceryProductsRequest.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInner.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInnerEstimatedCost.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInnerNutrition.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInnerNutritionCaloricBreakdown.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInnerNutritionNutrientsInner.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInnerNutritionPropertiesInner.h>
#import <OpenAPIClient/OAIParseIngredients200ResponseInnerNutritionWeightPerServing.h>
#import <OpenAPIClient/OAIQuickAnswer200Response.h>
#import <OpenAPIClient/OAISearchAllFood200Response.h>
#import <OpenAPIClient/OAISearchAllFood200ResponseSearchResultsInner.h>
#import <OpenAPIClient/OAISearchAllFood200ResponseSearchResultsInnerResultsInner.h>
#import <OpenAPIClient/OAISearchCustomFoods200Response.h>
#import <OpenAPIClient/OAISearchCustomFoods200ResponseCustomFoodsInner.h>
#import <OpenAPIClient/OAISearchFoodVideos200Response.h>
#import <OpenAPIClient/OAISearchFoodVideos200ResponseVideosInner.h>
#import <OpenAPIClient/OAISearchGroceryProducts200Response.h>
#import <OpenAPIClient/OAISearchGroceryProductsByUPC200Response.h>
#import <OpenAPIClient/OAISearchGroceryProductsByUPC200ResponseIngredientsInner.h>
#import <OpenAPIClient/OAISearchGroceryProductsByUPC200ResponseNutrition.h>
#import <OpenAPIClient/OAISearchGroceryProductsByUPC200ResponseServings.h>
#import <OpenAPIClient/OAISearchMenuItems200Response.h>
#import <OpenAPIClient/OAISearchMenuItems200ResponseMenuItemsInner.h>
#import <OpenAPIClient/OAISearchRecipes200Response.h>
#import <OpenAPIClient/OAISearchRecipes200ResponseResultsInner.h>
#import <OpenAPIClient/OAISearchRecipesByIngredients200ResponseInner.h>
#import <OpenAPIClient/OAISearchRecipesByIngredients200ResponseInnerMissedIngredientsInner.h>
#import <OpenAPIClient/OAISearchRecipesByNutrients200ResponseInner.h>
#import <OpenAPIClient/OAISearchRestaurants200Response.h>
#import <OpenAPIClient/OAISearchRestaurants200ResponseRestaurantsInner.h>
#import <OpenAPIClient/OAISearchRestaurants200ResponseRestaurantsInnerAddress.h>
#import <OpenAPIClient/OAISearchRestaurants200ResponseRestaurantsInnerLocalHours.h>
#import <OpenAPIClient/OAISearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational.h>
#import <OpenAPIClient/OAISearchSiteContent200Response.h>
#import <OpenAPIClient/OAISearchSiteContent200ResponseArticlesInner.h>
#import <OpenAPIClient/OAISearchSiteContent200ResponseGroceryProductsInner.h>
#import <OpenAPIClient/OAISearchSiteContent200ResponseGroceryProductsInnerDataPointsInner.h>
#import <OpenAPIClient/OAISummarizeRecipe200Response.h>
#import <OpenAPIClient/OAITalkToChatbot200Response.h>
// load API classes for accessing endpoints
#import <OpenAPIClient/OAIDefaultApi.h>
#import <OpenAPIClient/OAIIngredientsApi.h>
#import <OpenAPIClient/OAIMealPlanningApi.h>
#import <OpenAPIClient/OAIMenuItemsApi.h>
#import <OpenAPIClient/OAIMiscApi.h>
#import <OpenAPIClient/OAIProductsApi.h>
#import <OpenAPIClient/OAIRecipesApi.h>
#import <OpenAPIClient/OAIWineApi.h>

```

## Recommendation

It's recommended to create an instance of ApiClient per thread in a multi-threaded environment to avoid any potential issues.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```objc

OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyScheme)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"x-api-key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"x-api-key"];


OAIAnalyzeRecipeRequest* *analyzeRecipeRequest = [[OAIAnalyzeRecipeRequest alloc] init]; // Example request body.
NSString* *language = en; // The input language, either \"en\" or \"de\". (optional)
NSNumber* *includeNutrition = false; // Whether nutrition data should be added to correctly parsed ingredients. (optional)
NSNumber* *includeTaste = false; // Whether taste data should be added to correctly parsed ingredients. (optional)

OAIDefaultApi *apiInstance = [[OAIDefaultApi alloc] init];

// Analyze Recipe
[apiInstance analyzeRecipeWithAnalyzeRecipeRequest:analyzeRecipeRequest
    language:language
    includeNutrition:includeNutrition
    includeTaste:includeTaste
              completionHandler: ^(NSObject* output, NSError* error) {
                            if (output) {
                                NSLog(@"%@", output);
                            }
                            if (error) {
                                NSLog(@"Error: %@", error);
                            }
                        }];

```

## Documentation for API Endpoints

All URIs are relative to *https://api.spoonacular.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OAIDefaultApi* | [**analyzeRecipe**](docs/OAIDefaultApi.md#analyzerecipe) | **POST** /recipes/analyze | Analyze Recipe
*OAIDefaultApi* | [**createRecipeCardGet**](docs/OAIDefaultApi.md#createrecipecardget) | **GET** /recipes/{id}/card | Create Recipe Card
*OAIDefaultApi* | [**searchRestaurants**](docs/OAIDefaultApi.md#searchrestaurants) | **GET** /food/restaurants/search | Search Restaurants
*OAIIngredientsApi* | [**autocompleteIngredientSearch**](docs/OAIIngredientsApi.md#autocompleteingredientsearch) | **GET** /food/ingredients/autocomplete | Autocomplete Ingredient Search
*OAIIngredientsApi* | [**computeIngredientAmount**](docs/OAIIngredientsApi.md#computeingredientamount) | **GET** /food/ingredients/{id}/amount | Compute Ingredient Amount
*OAIIngredientsApi* | [**getIngredientInformation**](docs/OAIIngredientsApi.md#getingredientinformation) | **GET** /food/ingredients/{id}/information | Get Ingredient Information
*OAIIngredientsApi* | [**getIngredientSubstitutes**](docs/OAIIngredientsApi.md#getingredientsubstitutes) | **GET** /food/ingredients/substitutes | Get Ingredient Substitutes
*OAIIngredientsApi* | [**getIngredientSubstitutesByID**](docs/OAIIngredientsApi.md#getingredientsubstitutesbyid) | **GET** /food/ingredients/{id}/substitutes | Get Ingredient Substitutes by ID
*OAIIngredientsApi* | [**ingredientSearch**](docs/OAIIngredientsApi.md#ingredientsearch) | **GET** /food/ingredients/search | Ingredient Search
*OAIIngredientsApi* | [**ingredientsByIDImage**](docs/OAIIngredientsApi.md#ingredientsbyidimage) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*OAIIngredientsApi* | [**mapIngredientsToGroceryProducts**](docs/OAIIngredientsApi.md#mapingredientstogroceryproducts) | **POST** /food/ingredients/map | Map Ingredients to Grocery Products
*OAIIngredientsApi* | [**visualizeIngredients**](docs/OAIIngredientsApi.md#visualizeingredients) | **POST** /recipes/visualizeIngredients | Ingredients Widget
*OAIMealPlanningApi* | [**addMealPlanTemplate**](docs/OAIMealPlanningApi.md#addmealplantemplate) | **POST** /mealplanner/{username}/templates | Add Meal Plan Template
*OAIMealPlanningApi* | [**addToMealPlan**](docs/OAIMealPlanningApi.md#addtomealplan) | **POST** /mealplanner/{username}/items | Add to Meal Plan
*OAIMealPlanningApi* | [**addToShoppingList**](docs/OAIMealPlanningApi.md#addtoshoppinglist) | **POST** /mealplanner/{username}/shopping-list/items | Add to Shopping List
*OAIMealPlanningApi* | [**clearMealPlanDay**](docs/OAIMealPlanningApi.md#clearmealplanday) | **DELETE** /mealplanner/{username}/day/{date} | Clear Meal Plan Day
*OAIMealPlanningApi* | [**connectUser**](docs/OAIMealPlanningApi.md#connectuser) | **POST** /users/connect | Connect User
*OAIMealPlanningApi* | [**deleteFromMealPlan**](docs/OAIMealPlanningApi.md#deletefrommealplan) | **DELETE** /mealplanner/{username}/items/{id} | Delete from Meal Plan
*OAIMealPlanningApi* | [**deleteFromShoppingList**](docs/OAIMealPlanningApi.md#deletefromshoppinglist) | **DELETE** /mealplanner/{username}/shopping-list/items/{id} | Delete from Shopping List
*OAIMealPlanningApi* | [**deleteMealPlanTemplate**](docs/OAIMealPlanningApi.md#deletemealplantemplate) | **DELETE** /mealplanner/{username}/templates/{id} | Delete Meal Plan Template
*OAIMealPlanningApi* | [**generateMealPlan**](docs/OAIMealPlanningApi.md#generatemealplan) | **GET** /mealplanner/generate | Generate Meal Plan
*OAIMealPlanningApi* | [**generateShoppingList**](docs/OAIMealPlanningApi.md#generateshoppinglist) | **POST** /mealplanner/{username}/shopping-list/{start-date}/{end-date} | Generate Shopping List
*OAIMealPlanningApi* | [**getMealPlanTemplate**](docs/OAIMealPlanningApi.md#getmealplantemplate) | **GET** /mealplanner/{username}/templates/{id} | Get Meal Plan Template
*OAIMealPlanningApi* | [**getMealPlanTemplates**](docs/OAIMealPlanningApi.md#getmealplantemplates) | **GET** /mealplanner/{username}/templates | Get Meal Plan Templates
*OAIMealPlanningApi* | [**getMealPlanWeek**](docs/OAIMealPlanningApi.md#getmealplanweek) | **GET** /mealplanner/{username}/week/{start-date} | Get Meal Plan Week
*OAIMealPlanningApi* | [**getShoppingList**](docs/OAIMealPlanningApi.md#getshoppinglist) | **GET** /mealplanner/{username}/shopping-list | Get Shopping List
*OAIMenuItemsApi* | [**autocompleteMenuItemSearch**](docs/OAIMenuItemsApi.md#autocompletemenuitemsearch) | **GET** /food/menuItems/suggest | Autocomplete Menu Item Search
*OAIMenuItemsApi* | [**getMenuItemInformation**](docs/OAIMenuItemsApi.md#getmenuiteminformation) | **GET** /food/menuItems/{id} | Get Menu Item Information
*OAIMenuItemsApi* | [**menuItemNutritionByIDImage**](docs/OAIMenuItemsApi.md#menuitemnutritionbyidimage) | **GET** /food/menuItems/{id}/nutritionWidget.png | Menu Item Nutrition by ID Image
*OAIMenuItemsApi* | [**menuItemNutritionLabelImage**](docs/OAIMenuItemsApi.md#menuitemnutritionlabelimage) | **GET** /food/menuItems/{id}/nutritionLabel.png | Menu Item Nutrition Label Image
*OAIMenuItemsApi* | [**menuItemNutritionLabelWidget**](docs/OAIMenuItemsApi.md#menuitemnutritionlabelwidget) | **GET** /food/menuItems/{id}/nutritionLabel | Menu Item Nutrition Label Widget
*OAIMenuItemsApi* | [**searchMenuItems**](docs/OAIMenuItemsApi.md#searchmenuitems) | **GET** /food/menuItems/search | Search Menu Items
*OAIMenuItemsApi* | [**visualizeMenuItemNutritionByID**](docs/OAIMenuItemsApi.md#visualizemenuitemnutritionbyid) | **GET** /food/menuItems/{id}/nutritionWidget | Menu Item Nutrition by ID Widget
*OAIMiscApi* | [**detectFoodInText**](docs/OAIMiscApi.md#detectfoodintext) | **POST** /food/detect | Detect Food in Text
*OAIMiscApi* | [**getARandomFoodJoke**](docs/OAIMiscApi.md#getarandomfoodjoke) | **GET** /food/jokes/random | Random Food Joke
*OAIMiscApi* | [**getConversationSuggests**](docs/OAIMiscApi.md#getconversationsuggests) | **GET** /food/converse/suggest | Conversation Suggests
*OAIMiscApi* | [**getRandomFoodTrivia**](docs/OAIMiscApi.md#getrandomfoodtrivia) | **GET** /food/trivia/random | Random Food Trivia
*OAIMiscApi* | [**imageAnalysisByURL**](docs/OAIMiscApi.md#imageanalysisbyurl) | **GET** /food/images/analyze | Image Analysis by URL
*OAIMiscApi* | [**imageClassificationByURL**](docs/OAIMiscApi.md#imageclassificationbyurl) | **GET** /food/images/classify | Image Classification by URL
*OAIMiscApi* | [**searchAllFood**](docs/OAIMiscApi.md#searchallfood) | **GET** /food/search | Search All Food
*OAIMiscApi* | [**searchCustomFoods**](docs/OAIMiscApi.md#searchcustomfoods) | **GET** /food/customFoods/search | Search Custom Foods
*OAIMiscApi* | [**searchFoodVideos**](docs/OAIMiscApi.md#searchfoodvideos) | **GET** /food/videos/search | Search Food Videos
*OAIMiscApi* | [**searchSiteContent**](docs/OAIMiscApi.md#searchsitecontent) | **GET** /food/site/search | Search Site Content
*OAIMiscApi* | [**talkToChatbot**](docs/OAIMiscApi.md#talktochatbot) | **GET** /food/converse | Talk to Chatbot
*OAIProductsApi* | [**autocompleteProductSearch**](docs/OAIProductsApi.md#autocompleteproductsearch) | **GET** /food/products/suggest | Autocomplete Product Search
*OAIProductsApi* | [**classifyGroceryProduct**](docs/OAIProductsApi.md#classifygroceryproduct) | **POST** /food/products/classify | Classify Grocery Product
*OAIProductsApi* | [**classifyGroceryProductBulk**](docs/OAIProductsApi.md#classifygroceryproductbulk) | **POST** /food/products/classifyBatch | Classify Grocery Product Bulk
*OAIProductsApi* | [**getComparableProducts**](docs/OAIProductsApi.md#getcomparableproducts) | **GET** /food/products/upc/{upc}/comparable | Get Comparable Products
*OAIProductsApi* | [**getProductInformation**](docs/OAIProductsApi.md#getproductinformation) | **GET** /food/products/{id} | Get Product Information
*OAIProductsApi* | [**productNutritionByIDImage**](docs/OAIProductsApi.md#productnutritionbyidimage) | **GET** /food/products/{id}/nutritionWidget.png | Product Nutrition by ID Image
*OAIProductsApi* | [**productNutritionLabelImage**](docs/OAIProductsApi.md#productnutritionlabelimage) | **GET** /food/products/{id}/nutritionLabel.png | Product Nutrition Label Image
*OAIProductsApi* | [**productNutritionLabelWidget**](docs/OAIProductsApi.md#productnutritionlabelwidget) | **GET** /food/products/{id}/nutritionLabel | Product Nutrition Label Widget
*OAIProductsApi* | [**searchGroceryProducts**](docs/OAIProductsApi.md#searchgroceryproducts) | **GET** /food/products/search | Search Grocery Products
*OAIProductsApi* | [**searchGroceryProductsByUPC**](docs/OAIProductsApi.md#searchgroceryproductsbyupc) | **GET** /food/products/upc/{upc} | Search Grocery Products by UPC
*OAIProductsApi* | [**visualizeProductNutritionByID**](docs/OAIProductsApi.md#visualizeproductnutritionbyid) | **GET** /food/products/{id}/nutritionWidget | Product Nutrition by ID Widget
*OAIRecipesApi* | [**analyzeARecipeSearchQuery**](docs/OAIRecipesApi.md#analyzearecipesearchquery) | **GET** /recipes/queries/analyze | Analyze a Recipe Search Query
*OAIRecipesApi* | [**analyzeRecipeInstructions**](docs/OAIRecipesApi.md#analyzerecipeinstructions) | **POST** /recipes/analyzeInstructions | Analyze Recipe Instructions
*OAIRecipesApi* | [**autocompleteRecipeSearch**](docs/OAIRecipesApi.md#autocompleterecipesearch) | **GET** /recipes/autocomplete | Autocomplete Recipe Search
*OAIRecipesApi* | [**classifyCuisine**](docs/OAIRecipesApi.md#classifycuisine) | **POST** /recipes/cuisine | Classify Cuisine
*OAIRecipesApi* | [**computeGlycemicLoad**](docs/OAIRecipesApi.md#computeglycemicload) | **POST** /food/ingredients/glycemicLoad | Compute Glycemic Load
*OAIRecipesApi* | [**convertAmounts**](docs/OAIRecipesApi.md#convertamounts) | **GET** /recipes/convert | Convert Amounts
*OAIRecipesApi* | [**createRecipeCard**](docs/OAIRecipesApi.md#createrecipecard) | **POST** /recipes/visualizeRecipe | Create Recipe Card
*OAIRecipesApi* | [**equipmentByIDImage**](docs/OAIRecipesApi.md#equipmentbyidimage) | **GET** /recipes/{id}/equipmentWidget.png | Equipment by ID Image
*OAIRecipesApi* | [**extractRecipeFromWebsite**](docs/OAIRecipesApi.md#extractrecipefromwebsite) | **GET** /recipes/extract | Extract Recipe from Website
*OAIRecipesApi* | [**getAnalyzedRecipeInstructions**](docs/OAIRecipesApi.md#getanalyzedrecipeinstructions) | **GET** /recipes/{id}/analyzedInstructions | Get Analyzed Recipe Instructions
*OAIRecipesApi* | [**getRandomRecipes**](docs/OAIRecipesApi.md#getrandomrecipes) | **GET** /recipes/random | Get Random Recipes
*OAIRecipesApi* | [**getRecipeEquipmentByID**](docs/OAIRecipesApi.md#getrecipeequipmentbyid) | **GET** /recipes/{id}/equipmentWidget.json | Equipment by ID
*OAIRecipesApi* | [**getRecipeInformation**](docs/OAIRecipesApi.md#getrecipeinformation) | **GET** /recipes/{id}/information | Get Recipe Information
*OAIRecipesApi* | [**getRecipeInformationBulk**](docs/OAIRecipesApi.md#getrecipeinformationbulk) | **GET** /recipes/informationBulk | Get Recipe Information Bulk
*OAIRecipesApi* | [**getRecipeIngredientsByID**](docs/OAIRecipesApi.md#getrecipeingredientsbyid) | **GET** /recipes/{id}/ingredientWidget.json | Ingredients by ID
*OAIRecipesApi* | [**getRecipeNutritionWidgetByID**](docs/OAIRecipesApi.md#getrecipenutritionwidgetbyid) | **GET** /recipes/{id}/nutritionWidget.json | Nutrition by ID
*OAIRecipesApi* | [**getRecipePriceBreakdownByID**](docs/OAIRecipesApi.md#getrecipepricebreakdownbyid) | **GET** /recipes/{id}/priceBreakdownWidget.json | Price Breakdown by ID
*OAIRecipesApi* | [**getRecipeTasteByID**](docs/OAIRecipesApi.md#getrecipetastebyid) | **GET** /recipes/{id}/tasteWidget.json | Taste by ID
*OAIRecipesApi* | [**getSimilarRecipes**](docs/OAIRecipesApi.md#getsimilarrecipes) | **GET** /recipes/{id}/similar | Get Similar Recipes
*OAIRecipesApi* | [**guessNutritionByDishName**](docs/OAIRecipesApi.md#guessnutritionbydishname) | **GET** /recipes/guessNutrition | Guess Nutrition by Dish Name
*OAIRecipesApi* | [**ingredientsByIDImage**](docs/OAIRecipesApi.md#ingredientsbyidimage) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*OAIRecipesApi* | [**parseIngredients**](docs/OAIRecipesApi.md#parseingredients) | **POST** /recipes/parseIngredients | Parse Ingredients
*OAIRecipesApi* | [**priceBreakdownByIDImage**](docs/OAIRecipesApi.md#pricebreakdownbyidimage) | **GET** /recipes/{id}/priceBreakdownWidget.png | Price Breakdown by ID Image
*OAIRecipesApi* | [**quickAnswer**](docs/OAIRecipesApi.md#quickanswer) | **GET** /recipes/quickAnswer | Quick Answer
*OAIRecipesApi* | [**recipeNutritionByIDImage**](docs/OAIRecipesApi.md#recipenutritionbyidimage) | **GET** /recipes/{id}/nutritionWidget.png | Recipe Nutrition by ID Image
*OAIRecipesApi* | [**recipeNutritionLabelImage**](docs/OAIRecipesApi.md#recipenutritionlabelimage) | **GET** /recipes/{id}/nutritionLabel.png | Recipe Nutrition Label Image
*OAIRecipesApi* | [**recipeNutritionLabelWidget**](docs/OAIRecipesApi.md#recipenutritionlabelwidget) | **GET** /recipes/{id}/nutritionLabel | Recipe Nutrition Label Widget
*OAIRecipesApi* | [**recipeTasteByIDImage**](docs/OAIRecipesApi.md#recipetastebyidimage) | **GET** /recipes/{id}/tasteWidget.png | Recipe Taste by ID Image
*OAIRecipesApi* | [**searchRecipes**](docs/OAIRecipesApi.md#searchrecipes) | **GET** /recipes/complexSearch | Search Recipes
*OAIRecipesApi* | [**searchRecipesByIngredients**](docs/OAIRecipesApi.md#searchrecipesbyingredients) | **GET** /recipes/findByIngredients | Search Recipes by Ingredients
*OAIRecipesApi* | [**searchRecipesByNutrients**](docs/OAIRecipesApi.md#searchrecipesbynutrients) | **GET** /recipes/findByNutrients | Search Recipes by Nutrients
*OAIRecipesApi* | [**summarizeRecipe**](docs/OAIRecipesApi.md#summarizerecipe) | **GET** /recipes/{id}/summary | Summarize Recipe
*OAIRecipesApi* | [**visualizeEquipment**](docs/OAIRecipesApi.md#visualizeequipment) | **POST** /recipes/visualizeEquipment | Equipment Widget
*OAIRecipesApi* | [**visualizePriceBreakdown**](docs/OAIRecipesApi.md#visualizepricebreakdown) | **POST** /recipes/visualizePriceEstimator | Price Breakdown Widget
*OAIRecipesApi* | [**visualizeRecipeEquipmentByID**](docs/OAIRecipesApi.md#visualizerecipeequipmentbyid) | **GET** /recipes/{id}/equipmentWidget | Equipment by ID Widget
*OAIRecipesApi* | [**visualizeRecipeIngredientsByID**](docs/OAIRecipesApi.md#visualizerecipeingredientsbyid) | **GET** /recipes/{id}/ingredientWidget | Ingredients by ID Widget
*OAIRecipesApi* | [**visualizeRecipeNutrition**](docs/OAIRecipesApi.md#visualizerecipenutrition) | **POST** /recipes/visualizeNutrition | Recipe Nutrition Widget
*OAIRecipesApi* | [**visualizeRecipeNutritionByID**](docs/OAIRecipesApi.md#visualizerecipenutritionbyid) | **GET** /recipes/{id}/nutritionWidget | Recipe Nutrition by ID Widget
*OAIRecipesApi* | [**visualizeRecipePriceBreakdownByID**](docs/OAIRecipesApi.md#visualizerecipepricebreakdownbyid) | **GET** /recipes/{id}/priceBreakdownWidget | Price Breakdown by ID Widget
*OAIRecipesApi* | [**visualizeRecipeTaste**](docs/OAIRecipesApi.md#visualizerecipetaste) | **POST** /recipes/visualizeTaste | Recipe Taste Widget
*OAIRecipesApi* | [**visualizeRecipeTasteByID**](docs/OAIRecipesApi.md#visualizerecipetastebyid) | **GET** /recipes/{id}/tasteWidget | Recipe Taste by ID Widget
*OAIWineApi* | [**getDishPairingForWine**](docs/OAIWineApi.md#getdishpairingforwine) | **GET** /food/wine/dishes | Dish Pairing for Wine
*OAIWineApi* | [**getWineDescription**](docs/OAIWineApi.md#getwinedescription) | **GET** /food/wine/description | Wine Description
*OAIWineApi* | [**getWinePairing**](docs/OAIWineApi.md#getwinepairing) | **GET** /food/wine/pairing | Wine Pairing
*OAIWineApi* | [**getWineRecommendation**](docs/OAIWineApi.md#getwinerecommendation) | **GET** /food/wine/recommendation | Wine Recommendation


## Documentation For Models

 - [OAIAddMealPlanTemplate200Response](docs/OAIAddMealPlanTemplate200Response.md)
 - [OAIAddMealPlanTemplate200ResponseItemsInner](docs/OAIAddMealPlanTemplate200ResponseItemsInner.md)
 - [OAIAddMealPlanTemplate200ResponseItemsInnerValue](docs/OAIAddMealPlanTemplate200ResponseItemsInnerValue.md)
 - [OAIAddToMealPlanRequest](docs/OAIAddToMealPlanRequest.md)
 - [OAIAddToMealPlanRequest1](docs/OAIAddToMealPlanRequest1.md)
 - [OAIAddToMealPlanRequest1Value](docs/OAIAddToMealPlanRequest1Value.md)
 - [OAIAddToMealPlanRequest1ValueIngredientsInner](docs/OAIAddToMealPlanRequest1ValueIngredientsInner.md)
 - [OAIAddToShoppingListRequest](docs/OAIAddToShoppingListRequest.md)
 - [OAIAnalyzeARecipeSearchQuery200Response](docs/OAIAnalyzeARecipeSearchQuery200Response.md)
 - [OAIAnalyzeARecipeSearchQuery200ResponseDishesInner](docs/OAIAnalyzeARecipeSearchQuery200ResponseDishesInner.md)
 - [OAIAnalyzeARecipeSearchQuery200ResponseIngredientsInner](docs/OAIAnalyzeARecipeSearchQuery200ResponseIngredientsInner.md)
 - [OAIAnalyzeRecipeInstructions200Response](docs/OAIAnalyzeRecipeInstructions200Response.md)
 - [OAIAnalyzeRecipeInstructions200ResponseIngredientsInner](docs/OAIAnalyzeRecipeInstructions200ResponseIngredientsInner.md)
 - [OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInner](docs/OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/OAIAnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [OAIAnalyzeRecipeRequest](docs/OAIAnalyzeRecipeRequest.md)
 - [OAIAnalyzeRecipeRequest1](docs/OAIAnalyzeRecipeRequest1.md)
 - [OAIAutocompleteIngredientSearch200ResponseInner](docs/OAIAutocompleteIngredientSearch200ResponseInner.md)
 - [OAIAutocompleteMenuItemSearch200Response](docs/OAIAutocompleteMenuItemSearch200Response.md)
 - [OAIAutocompleteProductSearch200Response](docs/OAIAutocompleteProductSearch200Response.md)
 - [OAIAutocompleteProductSearch200ResponseResultsInner](docs/OAIAutocompleteProductSearch200ResponseResultsInner.md)
 - [OAIAutocompleteRecipeSearch200ResponseInner](docs/OAIAutocompleteRecipeSearch200ResponseInner.md)
 - [OAIClassifyCuisine200Response](docs/OAIClassifyCuisine200Response.md)
 - [OAIClassifyGroceryProduct200Response](docs/OAIClassifyGroceryProduct200Response.md)
 - [OAIClassifyGroceryProductBulk200ResponseInner](docs/OAIClassifyGroceryProductBulk200ResponseInner.md)
 - [OAIClassifyGroceryProductBulkRequestInner](docs/OAIClassifyGroceryProductBulkRequestInner.md)
 - [OAIClassifyGroceryProductRequest](docs/OAIClassifyGroceryProductRequest.md)
 - [OAIClearMealPlanDayRequest](docs/OAIClearMealPlanDayRequest.md)
 - [OAIComputeGlycemicLoad200Response](docs/OAIComputeGlycemicLoad200Response.md)
 - [OAIComputeGlycemicLoad200ResponseIngredientsInner](docs/OAIComputeGlycemicLoad200ResponseIngredientsInner.md)
 - [OAIComputeGlycemicLoadRequest](docs/OAIComputeGlycemicLoadRequest.md)
 - [OAIComputeIngredientAmount200Response](docs/OAIComputeIngredientAmount200Response.md)
 - [OAIConnectUser200Response](docs/OAIConnectUser200Response.md)
 - [OAIConnectUserRequest](docs/OAIConnectUserRequest.md)
 - [OAIConvertAmounts200Response](docs/OAIConvertAmounts200Response.md)
 - [OAICreateRecipeCard200Response](docs/OAICreateRecipeCard200Response.md)
 - [OAIDeleteFromMealPlanRequest](docs/OAIDeleteFromMealPlanRequest.md)
 - [OAIDetectFoodInText200Response](docs/OAIDetectFoodInText200Response.md)
 - [OAIDetectFoodInText200ResponseAnnotationsInner](docs/OAIDetectFoodInText200ResponseAnnotationsInner.md)
 - [OAIGenerateMealPlan200Response](docs/OAIGenerateMealPlan200Response.md)
 - [OAIGenerateMealPlan200ResponseNutrients](docs/OAIGenerateMealPlan200ResponseNutrients.md)
 - [OAIGenerateShoppingList200Response](docs/OAIGenerateShoppingList200Response.md)
 - [OAIGenerateShoppingListRequest](docs/OAIGenerateShoppingListRequest.md)
 - [OAIGetARandomFoodJoke200Response](docs/OAIGetARandomFoodJoke200Response.md)
 - [OAIGetAnalyzedRecipeInstructions200Response](docs/OAIGetAnalyzedRecipeInstructions200Response.md)
 - [OAIGetAnalyzedRecipeInstructions200ResponseIngredientsInner](docs/OAIGetAnalyzedRecipeInstructions200ResponseIngredientsInner.md)
 - [OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner](docs/OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/OAIGetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [OAIGetComparableProducts200Response](docs/OAIGetComparableProducts200Response.md)
 - [OAIGetComparableProducts200ResponseComparableProducts](docs/OAIGetComparableProducts200ResponseComparableProducts.md)
 - [OAIGetComparableProducts200ResponseComparableProductsProteinInner](docs/OAIGetComparableProducts200ResponseComparableProductsProteinInner.md)
 - [OAIGetConversationSuggests200Response](docs/OAIGetConversationSuggests200Response.md)
 - [OAIGetConversationSuggests200ResponseSuggests](docs/OAIGetConversationSuggests200ResponseSuggests.md)
 - [OAIGetConversationSuggests200ResponseSuggestsInner](docs/OAIGetConversationSuggests200ResponseSuggestsInner.md)
 - [OAIGetDishPairingForWine200Response](docs/OAIGetDishPairingForWine200Response.md)
 - [OAIGetIngredientInformation200Response](docs/OAIGetIngredientInformation200Response.md)
 - [OAIGetIngredientInformation200ResponseNutrition](docs/OAIGetIngredientInformation200ResponseNutrition.md)
 - [OAIGetIngredientSubstitutes200Response](docs/OAIGetIngredientSubstitutes200Response.md)
 - [OAIGetMealPlanTemplate200Response](docs/OAIGetMealPlanTemplate200Response.md)
 - [OAIGetMealPlanTemplate200ResponseDaysInner](docs/OAIGetMealPlanTemplate200ResponseDaysInner.md)
 - [OAIGetMealPlanTemplate200ResponseDaysInnerItemsInner](docs/OAIGetMealPlanTemplate200ResponseDaysInnerItemsInner.md)
 - [OAIGetMealPlanTemplate200ResponseDaysInnerItemsInnerValue](docs/OAIGetMealPlanTemplate200ResponseDaysInnerItemsInnerValue.md)
 - [OAIGetMealPlanTemplates200Response](docs/OAIGetMealPlanTemplates200Response.md)
 - [OAIGetMealPlanWeek200Response](docs/OAIGetMealPlanWeek200Response.md)
 - [OAIGetMealPlanWeek200ResponseDaysInner](docs/OAIGetMealPlanWeek200ResponseDaysInner.md)
 - [OAIGetMealPlanWeek200ResponseDaysInnerItemsInner](docs/OAIGetMealPlanWeek200ResponseDaysInnerItemsInner.md)
 - [OAIGetMealPlanWeek200ResponseDaysInnerItemsInnerValue](docs/OAIGetMealPlanWeek200ResponseDaysInnerItemsInnerValue.md)
 - [OAIGetMealPlanWeek200ResponseDaysInnerNutritionSummary](docs/OAIGetMealPlanWeek200ResponseDaysInnerNutritionSummary.md)
 - [OAIGetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner](docs/OAIGetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner.md)
 - [OAIGetMenuItemInformation200Response](docs/OAIGetMenuItemInformation200Response.md)
 - [OAIGetProductInformation200Response](docs/OAIGetProductInformation200Response.md)
 - [OAIGetProductInformation200ResponseIngredientsInner](docs/OAIGetProductInformation200ResponseIngredientsInner.md)
 - [OAIGetRandomFoodTrivia200Response](docs/OAIGetRandomFoodTrivia200Response.md)
 - [OAIGetRandomRecipes200Response](docs/OAIGetRandomRecipes200Response.md)
 - [OAIGetRandomRecipes200ResponseRecipesInner](docs/OAIGetRandomRecipes200ResponseRecipesInner.md)
 - [OAIGetRecipeEquipmentByID200Response](docs/OAIGetRecipeEquipmentByID200Response.md)
 - [OAIGetRecipeEquipmentByID200ResponseEquipmentInner](docs/OAIGetRecipeEquipmentByID200ResponseEquipmentInner.md)
 - [OAIGetRecipeInformation200Response](docs/OAIGetRecipeInformation200Response.md)
 - [OAIGetRecipeInformation200ResponseExtendedIngredientsInner](docs/OAIGetRecipeInformation200ResponseExtendedIngredientsInner.md)
 - [OAIGetRecipeInformation200ResponseExtendedIngredientsInnerMeasures](docs/OAIGetRecipeInformation200ResponseExtendedIngredientsInnerMeasures.md)
 - [OAIGetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric](docs/OAIGetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric.md)
 - [OAIGetRecipeInformation200ResponseWinePairing](docs/OAIGetRecipeInformation200ResponseWinePairing.md)
 - [OAIGetRecipeInformation200ResponseWinePairingProductMatchesInner](docs/OAIGetRecipeInformation200ResponseWinePairingProductMatchesInner.md)
 - [OAIGetRecipeInformationBulk200ResponseInner](docs/OAIGetRecipeInformationBulk200ResponseInner.md)
 - [OAIGetRecipeIngredientsByID200Response](docs/OAIGetRecipeIngredientsByID200Response.md)
 - [OAIGetRecipeIngredientsByID200ResponseIngredientsInner](docs/OAIGetRecipeIngredientsByID200ResponseIngredientsInner.md)
 - [OAIGetRecipeNutritionWidgetByID200Response](docs/OAIGetRecipeNutritionWidgetByID200Response.md)
 - [OAIGetRecipeNutritionWidgetByID200ResponseBadInner](docs/OAIGetRecipeNutritionWidgetByID200ResponseBadInner.md)
 - [OAIGetRecipeNutritionWidgetByID200ResponseGoodInner](docs/OAIGetRecipeNutritionWidgetByID200ResponseGoodInner.md)
 - [OAIGetRecipePriceBreakdownByID200Response](docs/OAIGetRecipePriceBreakdownByID200Response.md)
 - [OAIGetRecipePriceBreakdownByID200ResponseIngredientsInner](docs/OAIGetRecipePriceBreakdownByID200ResponseIngredientsInner.md)
 - [OAIGetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount](docs/OAIGetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount.md)
 - [OAIGetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric](docs/OAIGetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric.md)
 - [OAIGetRecipeTasteByID200Response](docs/OAIGetRecipeTasteByID200Response.md)
 - [OAIGetShoppingList200Response](docs/OAIGetShoppingList200Response.md)
 - [OAIGetShoppingList200ResponseAislesInner](docs/OAIGetShoppingList200ResponseAislesInner.md)
 - [OAIGetShoppingList200ResponseAislesInnerItemsInner](docs/OAIGetShoppingList200ResponseAislesInnerItemsInner.md)
 - [OAIGetShoppingList200ResponseAislesInnerItemsInnerMeasures](docs/OAIGetShoppingList200ResponseAislesInnerItemsInnerMeasures.md)
 - [OAIGetSimilarRecipes200ResponseInner](docs/OAIGetSimilarRecipes200ResponseInner.md)
 - [OAIGetWineDescription200Response](docs/OAIGetWineDescription200Response.md)
 - [OAIGetWinePairing200Response](docs/OAIGetWinePairing200Response.md)
 - [OAIGetWinePairing200ResponseProductMatchesInner](docs/OAIGetWinePairing200ResponseProductMatchesInner.md)
 - [OAIGetWineRecommendation200Response](docs/OAIGetWineRecommendation200Response.md)
 - [OAIGetWineRecommendation200ResponseRecommendedWinesInner](docs/OAIGetWineRecommendation200ResponseRecommendedWinesInner.md)
 - [OAIGuessNutritionByDishName200Response](docs/OAIGuessNutritionByDishName200Response.md)
 - [OAIGuessNutritionByDishName200ResponseCalories](docs/OAIGuessNutritionByDishName200ResponseCalories.md)
 - [OAIGuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent](docs/OAIGuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent.md)
 - [OAIImageAnalysisByURL200Response](docs/OAIImageAnalysisByURL200Response.md)
 - [OAIImageAnalysisByURL200ResponseCategory](docs/OAIImageAnalysisByURL200ResponseCategory.md)
 - [OAIImageAnalysisByURL200ResponseNutrition](docs/OAIImageAnalysisByURL200ResponseNutrition.md)
 - [OAIImageAnalysisByURL200ResponseNutritionCalories](docs/OAIImageAnalysisByURL200ResponseNutritionCalories.md)
 - [OAIImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent](docs/OAIImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent.md)
 - [OAIImageAnalysisByURL200ResponseRecipesInner](docs/OAIImageAnalysisByURL200ResponseRecipesInner.md)
 - [OAIImageClassificationByURL200Response](docs/OAIImageClassificationByURL200Response.md)
 - [OAIIngredientSearch200Response](docs/OAIIngredientSearch200Response.md)
 - [OAIIngredientSearch200ResponseResultsInner](docs/OAIIngredientSearch200ResponseResultsInner.md)
 - [OAIMapIngredientsToGroceryProducts200ResponseInner](docs/OAIMapIngredientsToGroceryProducts200ResponseInner.md)
 - [OAIMapIngredientsToGroceryProducts200ResponseInnerProductsInner](docs/OAIMapIngredientsToGroceryProducts200ResponseInnerProductsInner.md)
 - [OAIMapIngredientsToGroceryProductsRequest](docs/OAIMapIngredientsToGroceryProductsRequest.md)
 - [OAIParseIngredients200ResponseInner](docs/OAIParseIngredients200ResponseInner.md)
 - [OAIParseIngredients200ResponseInnerEstimatedCost](docs/OAIParseIngredients200ResponseInnerEstimatedCost.md)
 - [OAIParseIngredients200ResponseInnerNutrition](docs/OAIParseIngredients200ResponseInnerNutrition.md)
 - [OAIParseIngredients200ResponseInnerNutritionCaloricBreakdown](docs/OAIParseIngredients200ResponseInnerNutritionCaloricBreakdown.md)
 - [OAIParseIngredients200ResponseInnerNutritionNutrientsInner](docs/OAIParseIngredients200ResponseInnerNutritionNutrientsInner.md)
 - [OAIParseIngredients200ResponseInnerNutritionPropertiesInner](docs/OAIParseIngredients200ResponseInnerNutritionPropertiesInner.md)
 - [OAIParseIngredients200ResponseInnerNutritionWeightPerServing](docs/OAIParseIngredients200ResponseInnerNutritionWeightPerServing.md)
 - [OAIQuickAnswer200Response](docs/OAIQuickAnswer200Response.md)
 - [OAISearchAllFood200Response](docs/OAISearchAllFood200Response.md)
 - [OAISearchAllFood200ResponseSearchResultsInner](docs/OAISearchAllFood200ResponseSearchResultsInner.md)
 - [OAISearchAllFood200ResponseSearchResultsInnerResultsInner](docs/OAISearchAllFood200ResponseSearchResultsInnerResultsInner.md)
 - [OAISearchCustomFoods200Response](docs/OAISearchCustomFoods200Response.md)
 - [OAISearchCustomFoods200ResponseCustomFoodsInner](docs/OAISearchCustomFoods200ResponseCustomFoodsInner.md)
 - [OAISearchFoodVideos200Response](docs/OAISearchFoodVideos200Response.md)
 - [OAISearchFoodVideos200ResponseVideosInner](docs/OAISearchFoodVideos200ResponseVideosInner.md)
 - [OAISearchGroceryProducts200Response](docs/OAISearchGroceryProducts200Response.md)
 - [OAISearchGroceryProductsByUPC200Response](docs/OAISearchGroceryProductsByUPC200Response.md)
 - [OAISearchGroceryProductsByUPC200ResponseIngredientsInner](docs/OAISearchGroceryProductsByUPC200ResponseIngredientsInner.md)
 - [OAISearchGroceryProductsByUPC200ResponseNutrition](docs/OAISearchGroceryProductsByUPC200ResponseNutrition.md)
 - [OAISearchGroceryProductsByUPC200ResponseServings](docs/OAISearchGroceryProductsByUPC200ResponseServings.md)
 - [OAISearchMenuItems200Response](docs/OAISearchMenuItems200Response.md)
 - [OAISearchMenuItems200ResponseMenuItemsInner](docs/OAISearchMenuItems200ResponseMenuItemsInner.md)
 - [OAISearchRecipes200Response](docs/OAISearchRecipes200Response.md)
 - [OAISearchRecipes200ResponseResultsInner](docs/OAISearchRecipes200ResponseResultsInner.md)
 - [OAISearchRecipesByIngredients200ResponseInner](docs/OAISearchRecipesByIngredients200ResponseInner.md)
 - [OAISearchRecipesByIngredients200ResponseInnerMissedIngredientsInner](docs/OAISearchRecipesByIngredients200ResponseInnerMissedIngredientsInner.md)
 - [OAISearchRecipesByNutrients200ResponseInner](docs/OAISearchRecipesByNutrients200ResponseInner.md)
 - [OAISearchRestaurants200Response](docs/OAISearchRestaurants200Response.md)
 - [OAISearchRestaurants200ResponseRestaurantsInner](docs/OAISearchRestaurants200ResponseRestaurantsInner.md)
 - [OAISearchRestaurants200ResponseRestaurantsInnerAddress](docs/OAISearchRestaurants200ResponseRestaurantsInnerAddress.md)
 - [OAISearchRestaurants200ResponseRestaurantsInnerLocalHours](docs/OAISearchRestaurants200ResponseRestaurantsInnerLocalHours.md)
 - [OAISearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational](docs/OAISearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [OAISearchSiteContent200Response](docs/OAISearchSiteContent200Response.md)
 - [OAISearchSiteContent200ResponseArticlesInner](docs/OAISearchSiteContent200ResponseArticlesInner.md)
 - [OAISearchSiteContent200ResponseGroceryProductsInner](docs/OAISearchSiteContent200ResponseGroceryProductsInner.md)
 - [OAISearchSiteContent200ResponseGroceryProductsInnerDataPointsInner](docs/OAISearchSiteContent200ResponseGroceryProductsInnerDataPointsInner.md)
 - [OAISummarizeRecipe200Response](docs/OAISummarizeRecipe200Response.md)
 - [OAITalkToChatbot200Response](docs/OAITalkToChatbot200Response.md)


## Documentation For Authorization


Authentication schemes defined for the API:
### apiKeyScheme

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author

mail@spoonacular.com

